@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2002 by Gunnar Schmi Dt <kmouth@schmi-dt.de             *
- *             (C) 2015 by Jeremy Whiting <jpwhiting@kde.org>              *
+ *             (C) 2015, 2022 by Jeremy Whiting <jpwhiting@kde.org>        *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -29,13 +29,14 @@
 #include "speech.h"
 
 TextToSpeechSystem::TextToSpeechSystem(QObject *parent)
-    : QObject(parent)
+    : QObject(parent),
+      codec(Speech::Local),
+      stdIn(true),
+      useQtSpeech(true),
+      ttsEngine(QLatin1String("speechd")),
+      m_speech(new QTextToSpeech(ttsEngine))
 {
-    stdIn = true;
-    useQtSpeech = true;
-    codec = Speech::Local; // local encoding;
     buildCodecList();
-    m_speech = new QTextToSpeech();
 }
 
 TextToSpeechSystem::~TextToSpeechSystem()
@@ -66,6 +67,10 @@ void TextToSpeechSystem::readOptions(const QString &langGroup)
     ttsCommand = cg.readPathEntry("Command", QString());
     stdIn = cg.readEntry("StdIn", true);
     useQtSpeech = cg.readEntry("useQtSpeech", true);
+    ttsEngine = cg.readEntry("ttsEngine", "speechd");
+    // No default, depends on current locale, etc. so just naturally
+    // select first voice if none set by user.
+    ttsVoice = cg.readEntry("ttsVoice", "");
 
     QString codecString = cg.readEntry("Codec", "Local");
     if (codecString == QLatin1String("Local"))
@@ -88,6 +93,8 @@ void TextToSpeechSystem::saveOptions(const QString &langGroup)
     cg.writePathEntry("Command", ttsCommand);
     cg.writeEntry("StdIn", stdIn);
     cg.writeEntry("useQtSpeech", useQtSpeech);
+    cg.writeEntry("ttsEngine", ttsEngine);
+    cg.writeEntry("ttsVoice", ttsVoice);
     if (codec == Speech::Local)
         cg.writeEntry("Codec", "Local");
     else if (codec == Speech::Latin1)
@@ -98,6 +105,15 @@ void TextToSpeechSystem::saveOptions(const QString &langGroup)
         QString codeName = QLatin1String(codecList->at(codec - Speech::UseCodec)->name());
         cg.writeEntry("Codec", codeName);
     }
+
+    delete m_speech;
+    m_speech = new QTextToSpeech(ttsEngine);
+    const QVector<QVoice> voices = m_speech->availableVoices();
+    for (const QVoice &voice: voices) {
+        if (voice.name() == ttsVoice) {
+            m_speech->setVoice(voice);
+        }
+    }
 }
 
 void TextToSpeechSystem::buildCodecList()
