@@ -28,8 +28,6 @@
 #include <QStandardPaths>
 #include <QTextCodec>
 #include <QTextStream>
-#include <QXmlInputSource>
-#include <QXmlSimpleReader>
 
 #include <KLocalizedString>
 
@@ -90,8 +88,9 @@ bool saveWordList(const WordMap &map, const QString &filename)
         return false;
 
     QTextStream stream(&file);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     stream.setCodec("UTF-8");
-
+#endif
     stream << "WPDictFile\n";
     WordMap::ConstIterator it;
     for (it = map.constBegin(); it != map.constEnd(); ++it)
@@ -139,7 +138,9 @@ void addWordsFromFile(WordMap &map, const QString &filename, QTextCodec *codec)
         QFile wpdfile(filename);
         if (wpdfile.open(QIODevice::ReadOnly)) {
             QTextStream stream(&wpdfile);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             stream.setCodec("UTF-8");
+#endif
 
             if (!stream.atEnd()) {
                 QString line = stream.readLine();
